@@ -3,40 +3,54 @@ package App::whichdll;
 use strict;
 use warnings;
 use 5.008001;
-use FFI::CheckLib 0.05 qw( find_lib );
-use Getopt::Std qw( getopts );
+use FFI::CheckLib 0.28 qw( find_lib );
+use Getopt::Long qw( GetOptions );
 use Path::Tiny qw( path );
 
 # ABSTRACT: Find dynamic libraries
-our $VERSION = '0.03'; # VERSION
+our $VERSION = '0.04'; # VERSION
 
 
 sub main
 {
   local @ARGV;
   (undef, @ARGV) = @_;
-  
+
   my %opts;
-  
-  getopts('avsx', \%opts) || return _usage();
+
+  my @alien;
+
+  GetOptions(
+    "a"       => \$opts{a},
+    "v"       => \$opts{v},
+    "s"       => \$opts{s},
+    "x"       => \$opts{x},
+    "alien=s" => \@alien,
+  ) || return _usage();
   return _version() if $opts{v};
   return _usage()   unless @ARGV;
-  
+
   my %seen;
-  
+
+  my @extra_args;
+  if(@alien)
+  {
+    push @extra_args, alien => \@alien;
+  }
+
   foreach my $name (@ARGV)
   {
     my @result;
     if($opts{a} || $name eq '*')
     {
-      @result = find_lib( lib => '*', verify => sub { ($name eq '*') || ($_[0] eq $name) });
+      @result = find_lib( lib => '*', verify => sub { ($name eq '*') || ($_[0] eq $name) }, @extra_args);
     }
     else
     {
-      my $result = find_lib( lib => $name );
+      my $result = find_lib( lib => $name, @extra_args );
       push @result, $result if defined $result;
     }
-    
+
     unless($opts{s})
     {
       foreach my $path (map { path($_) } @result)
@@ -65,14 +79,14 @@ sub main
         }
       }
     }
-    
+
     unless(@result)
     {
       print STDERR "$0: no $name in dynamic library path\n" unless $opts{s};
       return 1;
     }
   }
-  
+
   return 0;
 }
 
@@ -94,8 +108,9 @@ EOF
 sub _usage
 {
   print <<"EOF";
-Usage: $0 [-a] [-s] [-v] dllname [dllname ...]
+Usage: $0 [-a] [-s] [-v] [--alien Alien::Name] dllname [dllname ...]
        -a       Print all matches in dynamic library path.
+       --alien  Include Perl Aliens in search
        -v       Prints version and exits
        -s       Silent mode
        -x       Do not prune duplicates (due to symlinks, etc.)
@@ -116,7 +131,7 @@ App::whichdll - Find dynamic libraries
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 SYNOPSIS
 
@@ -145,7 +160,7 @@ Graham Ollis <plicease@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by Graham Ollis.
+This software is copyright (c) 2018-2022 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
